<?php

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class xorgcore_Abandoned_Trash_Orders_Table extends WP_List_Table {

	
	public $per_page = 30;

	
	public $base_url;

	
	public $total_count;

    
	public function __construct() {
		global $status, $page;
		
		parent::__construct( array(
	    	        'singular' => __( 'abandoned_order_id', 'xcart-tr' ), 
	    	        'plural'   => __( 'abandoned_order_ids', 'xcart-tr' ),
	    			'ajax'     => false             			                 
    		    )
		);
		$this->process_bulk_action();
        $this->base_url = admin_url( 'admin.php?page=xcart&action=listcart' );
	}
	
	public function xorgcore_abandoned_order_prepare_items() {
		$columns               = $this->get_columns();
		$hidden                = array(); 
		$this->total_count     = $this->xorgcore_get_total_abandoned_count();
		$sortable              = $this->get_sortable_columns();
		$data                  = $this->xorgcore_abandoned_cart_data();
		$this->_column_headers = array( $columns, $hidden, $sortable);
		$total_items           = $this->total_count;

		if( count($data) > 0 ) {
		  $this->items = $data;
		} else {
		    $this->items = array();
		}
		$this->set_pagination_args( array(
				'total_items' => $total_items,                  	      
				'per_page'    => $this->per_page,                     	  
				'total_pages' => ceil( $total_items / $this->per_page )   
		      )
		);
	}
	
	public function get_columns() {
        $display_tracked_coupons = get_option( 'ac_track_coupons' );
        $columns                 = array();
        if( "on" == $display_tracked_coupons ) {
             $columns = array(
                'cb'                 => '<input type="checkbox" />',
                'id'                 => __( 'آی‌دی', 'xcart-tr' ),
                'customer'     		 => __( 'تلفن', 'xcart-tr' ),
                'order_total'  		 => __( 'سفارشات', 'xcart-tr' ),
                'date'               => __( 'تاریخ سفارش', 'xcart-tr' ),
                'status'             => __( 'وضعیت سبد خرید', 'xcart-tr' ),
                'xorgcore_actions' 		 => __( 'اطلاعات مهم', 'xcart-tr' )
            );
        } else {
        	$columns = array(
    	        'cb'                => '<input type="checkbox"/>',
                'id'                => __( 'Id', 'xcart-tr' ),
    	        'email'             => __( 'Email Address', 'xcart-tr' ),
    			'customer'     		=> __( 'تلفن', 'xcart-tr' ),
    			'order_total'  		=> __( 'Order Total', 'xcart-tr' ),
    	        'date'              => __( 'Abandoned Date', 'xcart-tr' ),
    			'status'            => __( 'Status of Cart', 'xcart-tr' ),
    			'xorgcore_actions' 		=> __( 'More info', 'xcart-tr' )
        	);
        }
    	return apply_filters( 'xorgcore_abandoned_orders_columns', $columns );
	}

	
	function column_cb( $item ) {
	    $abandoned_order_id = '';
	    if( isset( $item->id ) && "" != $item->id ) {
	       $abandoned_order_id = $item->id;
 	       return sprintf(
	           '<input type="checkbox" name="%1$s[]" value="%2$s" />',
	           'abandoned_order_id',
	           $abandoned_order_id
	       );
	    }
	}
	
	public function get_sortable_columns() {
		$columns = array(
				'date' 	 => array( 'date', false ),
				'status' => array( 'status',false ),
		);
		return apply_filters( 'xorgcore_abandoned_orders_sortable_columns', $columns );
	}

	
	public function column_email( $abandoned_row_info ) {
	    $row_actions       = array();
	    $value             = '';
	    $abandoned_order_id = 0;
	    if( isset( $abandoned_row_info->email ) ) {
    	    $abandoned_order_id               = $abandoned_row_info->id ;
    	    $row_actions['restore']            = '<a href="' . wp_nonce_url( add_query_arg( array( 'action' => 'xorgcore_abandoned_restore',    'abandoned_order_id' => $abandoned_row_info->id ), $this->base_url ), 'abandoned_order_nonce') . '">' . __( 'Restore', 'xcart-tr' ) . '</a>';

	        $row_actions['delete']            = '<a href="' . wp_nonce_url( add_query_arg( array( 'action' => 'xorgcore_abandoned_delete',    'abandoned_order_id' => $abandoned_row_info->id ), $this->base_url ), 'abandoned_order_nonce') . '">' . __( 'Delete Permanently', 'xcart-tr' ) . '</a>';
    	    $email                            = $abandoned_row_info->email;
    	    $value                            = $email . $this->row_actions( $row_actions );
	    }
	    return apply_filters( 'xorgcore_abandoned_trash_orders_single_column', $value, $abandoned_order_id, 'email' );
	}

	
	public function xorgcore_get_total_abandoned_count() {
	    global $wpdb;
	    $results                = array();
	    $blank_cart_info        = '{"cart":[]}';
	    $blank_cart_info_guest  = '[]';

	    $ac_cutoff_time 		= is_numeric( get_option( 'ac_cart_abandoned_time', 10 ) ) ? get_option( 'ac_cart_abandoned_time', 10 ) : 10;
	    $cut_off_time   		= $ac_cutoff_time * 60;
	    $current_time   		= current_time( 'timestamp' );
	    $compare_time   		= $current_time - $cut_off_time;

	    $ac_cutoff_time_guest  = is_numeric( get_option( 'ac_cart_abandoned_time_guest', 10 ) ) ? get_option( 'ac_cart_abandoned_time_guest', 10 ) : 10;
	    $cut_off_time_guest    = $ac_cutoff_time_guest * 60;
	    $current_time          = current_time ('timestamp');
	    $compare_time_guest    = $current_time - $cut_off_time_guest;
	    $xorgcore_class     	   = new xcart_ap();
		$duration_range 	   = "";
		if ( isset( $_POST['duration_select'] ) ) {
		    $duration_range = $_POST['duration_select'];
		}
		if( "" == $duration_range ) {
		    if ( isset( $_GET['duration_select'] ) && '' != $_GET['duration_select'] ) {
		        $duration_range = $_GET['duration_select'];
		    }
		}
		if ( isset( $_SESSION ['duration'] ) && '' != $_SESSION ['duration'] ) {
            $duration_range     = $_SESSION ['duration'];
		}

		if ( "" == $duration_range ) {
		    $duration_range = "last_seven";
		}
		$start_date_range = "";
        if ( isset( $_POST['start_date'] ) && '' != $_POST['start_date'] ){
            $start_date_range = $_POST['start_date'];
        }
        if ( isset( $_SESSION ['start_date'] ) &&  '' != $_SESSION ['start_date'] ) {
            $start_date_range = $_SESSION ['start_date'];
		}
		if ( "" == $start_date_range ) {
		   $start_date_range = $xorgcore_class->start_end_dates[$duration_range]['start_date'];
		}
		$end_date_range = "";
        if ( isset( $_POST['end_date'] ) && '' != $_POST['end_date'] ){
            $end_date_range = $_POST['end_date'];
        }

        if ( isset($_SESSION ['end_date'] ) && '' != $_SESSION ['end_date'] ){
            $end_date_range = $_SESSION ['end_date'];
		}

		if ( "" == $end_date_range ) {
		    $end_date_range = $xorgcore_class->start_end_dates[$duration_range]['end_date'];
		}

		$start_date = strtotime( $start_date_range." 00:01:01" );
		$end_date   = strtotime( $end_date_range." 23:59:59" );

		$status_filter = "( ( cart_ignored <> '1' AND recovered_cart = 0) OR ( cart_ignored = '1' AND recovered_cart > 0 ) ) ";
	    if( isset( $_POST[ 'cart_status' ] ) && '' != $_POST[ 'cart_status' ] ) {
	    	switch( $_POST[ 'cart_status' ] ) {
	    		case 'abandoned':
	    			$status_filter = "( cart_ignored = '0' AND recovered_cart = 0 ) ";
	    			break;
	    		case 'recovered':
	    			$status_filter = "( cart_ignored = '1' AND recovered_cart > 0 ) ";
	    			break;
	    		case 'unpaid':
	    			$status_filter = "( cart_ignored = '2' AND recovered_cart = 0 ) ";
	    			break;
	    		default:
	    			$status_filter = "( ( cart_ignored <> '1' AND recovered_cart = 0) OR ( cart_ignored = '1' AND recovered_cart > 0 ) ) ";
	    			break;
	    	}
	    }
	    
	    if( is_multisite() ) {
	        
	        $main_prefix = $wpdb->get_blog_prefix(1);
	        $query = "SELECT  * FROM `".xorgcore_ABANDONED_CART_HISTORY_TABLE."` WHERE ( user_type = 'REGISTERED' AND abandoned_cart_time >=  $start_date AND abandoned_cart_time <= $end_date AND abandoned_cart_info NOT LIKE '%$blank_cart_info%' AND abandoned_cart_time <= '$compare_time' AND xorgcore_trash = '1' AND $status_filter ) OR ( user_type = 'GUEST' AND abandoned_cart_time >=  $start_date AND abandoned_cart_time <= $end_date AND abandoned_cart_info NOT LIKE '$blank_cart_info_guest' AND abandoned_cart_info NOT LIKE '%$blank_cart_info%' AND abandoned_cart_time <= '$compare_time_guest' AND xorgcore_trash = '1' AND $status_filter ) ORDER BY abandoned_cart_time DESC";
	        $results = $wpdb->get_results($query);
	    } else {
	        
	        $query = "SELECT * FROM `".xorgcore_ABANDONED_CART_HISTORY_TABLE."` WHERE ( user_type = 'REGISTERED' AND abandoned_cart_time >=  $start_date AND abandoned_cart_time <= $end_date AND abandoned_cart_info NOT LIKE '%$blank_cart_info%' AND abandoned_cart_time <= '$compare_time' AND xorgcore_trash = '1' AND $status_filter ) OR ( user_type = 'GUEST' AND abandoned_cart_time >=  $start_date AND abandoned_cart_time <= $end_date AND abandoned_cart_info NOT LIKE '$blank_cart_info_guest' AND abandoned_cart_info NOT LIKE '%$blank_cart_info%' AND abandoned_cart_time <= '$compare_time_guest' AND xorgcore_trash = '1' AND $status_filter ) ORDER BY abandoned_cart_time DESC";
	        $results = $wpdb->get_results($query);
	    }
	    return count( $results );
	}
	
	public function xorgcore_abandoned_cart_data() {
	    global $wpdb, $woocommerce;
		$return_abandoned_orders = array();
		$per_page                = $this->per_page;
		$results                 = array();
		$blank_cart_info         = '{"cart":[]}';
		$blank_cart_info_guest   = '[]';

		if( isset( $_GET['paged'] ) && $_GET['paged'] > 1 ) {
		    $page_number = $_GET['paged'] - 1;
		    $start_limit = ( $per_page * $page_number );
		    $end_limit   =  $per_page;
		    $limit       = 'limit' .' '.$start_limit . ','. $end_limit;

		} else {
		    $start_limit = 0;
		    $end_limit   = $per_page;
		    $limit       = 'limit' .' '.$start_limit . ','. $end_limit;

		}
		$xorgcore_class     = new xcart_ap();
		$duration_range = "";
		if ( isset( $_POST['duration_select'] ) ) {
		    $duration_range = $_POST['duration_select'];
		}
		if( "" == $duration_range ) {
		    if ( isset( $_GET['duration_select'] ) && '' != $_GET['duration_select'] ) {
		        $duration_range = $_GET['duration_select'];
		    }
		}
		if ( isset( $_SESSION ['duration'] ) && '' != $_SESSION ['duration'] ) {
            $duration_range     = $_SESSION ['duration'];
		}

		if ( "" == $duration_range ) {
		    $duration_range = "last_seven";
		}
		$start_date_range = "";
        if ( isset( $_POST['start_date'] ) && '' != $_POST['start_date'] ){
            $start_date_range = $_POST['start_date'];
        }
        if ( isset( $_SESSION ['start_date'] ) &&  '' != $_SESSION ['start_date'] ) {
            $start_date_range = $_SESSION ['start_date'];
		}
		if ( "" == $start_date_range ) {
		   $start_date_range = $xorgcore_class->start_end_dates[$duration_range]['start_date'];
		}
		$end_date_range = "";
        if ( isset( $_POST['end_date'] ) && '' != $_POST['end_date'] ){
            $end_date_range = $_POST['end_date'];
        }

        if ( isset($_SESSION ['end_date'] ) && '' != $_SESSION ['end_date'] ){
            $end_date_range = $_SESSION ['end_date'];
		}

		if ( "" == $end_date_range ) {
		    $end_date_range = $xorgcore_class->start_end_dates[$duration_range]['end_date'];
		}

		$start_date = strtotime( $start_date_range." 00:01:01" );
		$end_date   = strtotime( $end_date_range." 23:59:59" );

		$status_filter = "( ( wpac.cart_ignored <> '1' AND wpac.recovered_cart = 0) OR ( wpac.cart_ignored = '1' AND wpac.recovered_cart > 0 ) ) ";
	    if( isset( $_POST[ 'cart_status' ] ) && '' != $_POST[ 'cart_status' ] ) {
	    	switch( $_POST[ 'cart_status' ] ) {
	    		case 'abandoned':
	    			$status_filter = "( wpac.cart_ignored = '0' AND wpac.recovered_cart = 0 ) ";
	    			break;
	    		case 'recovered':
	    			$status_filter = "( wpac.cart_ignored = '1' AND wpac.recovered_cart > 0 ) ";
	    			break;
	    		case 'unpaid':
	    			$status_filter = "( wpac.cart_ignored = '2' AND wpac.recovered_cart = 0 ) ";
	    			break;
	    		default:
	    			$status_filter = "( ( wpac.cart_ignored <> '1' AND wpac.recovered_cart = 0) OR ( wpac.cart_ignored = '1' AND wpac.recovered_cart > 0 ) ) ";
	    			break;
	    	}
	    }

		if( is_multisite() ) {
		    
		    $main_prefix = $wpdb->get_blog_prefix(1);
		    $query = "SELECT wpac . * , wpu.user_login, wpu.user_email FROM `".xorgcore_ABANDONED_CART_HISTORY_TABLE."` AS wpac LEFT JOIN ".$main_prefix."users AS wpu ON wpac.user_id = wpu.id WHERE wpac.abandoned_cart_time >=  $start_date AND wpac.abandoned_cart_time <= $end_date AND wpac.abandoned_cart_info NOT LIKE '%$blank_cart_info%' AND wpac.abandoned_cart_info NOT LIKE '$blank_cart_info_guest' AND wpac.xorgcore_trash = '1' AND $status_filter ORDER BY wpac.abandoned_cart_time DESC $limit";
		    $results = $wpdb->get_results($query);
		} else {
		    
		    $query = "SELECT wpac . * , wpu.user_login, wpu.user_email FROM `".xorgcore_ABANDONED_CART_HISTORY_TABLE."` AS wpac LEFT JOIN ".$wpdb->prefix."users AS wpu ON wpac.user_id = wpu.id WHERE wpac.abandoned_cart_time >=  $start_date AND wpac.abandoned_cart_time <= $end_date AND wpac.abandoned_cart_info NOT LIKE '%$blank_cart_info%' AND wpac.abandoned_cart_info NOT LIKE '$blank_cart_info_guest' AND wpac.xorgcore_trash = '1' AND $status_filter ORDER BY wpac.abandoned_cart_time DESC $limit";

		    $results = $wpdb->get_results($query);
		}

		$i = 0;
		$display_tracked_coupons = get_option( 'ac_track_coupons' );
		foreach( $results as $key => $value ) {
		    if( $value->user_type == "GUEST" ) {
		        $query_guest   = "SELECT * from `" . xorgcore_GUEST_CART_HISTORY_TABLE . "`
		                              WHERE id = %d";
		        $results_guest = $wpdb->get_results( $wpdb->prepare( $query_guest, $value->user_id ) );
		    }
		    $abandoned_order_id = $value->id;
		    $user_id            = $value->user_id;
		    $user_login         = $value->user_login;

		    if( $value->user_type == "GUEST" ) {
    		    if( isset( $results_guest[0]->email_id ) ) {
		            $user_email = $results_guest[0]->email_id;
		        } elseif ( $value->user_id == "0" ) {
		            $user_email = '';
		        } else {
		            $user_email = '';
	            }
		        if ( isset( $results_guest[0]->billing_first_name ) ) {
		            $user_first_name = $results_guest[0]->billing_first_name;
		        } else if( $value->user_id == "0" ) {
		            $user_first_name = "Visitor";
		        } else {
		            $user_first_name = "";
		        }
		        if( isset( $results_guest[0]->billing_last_name ) ) {
		            $user_last_name = $results_guest[0]->billing_last_name;
		        } else if( $value->user_id == "0" ) {
		            $user_last_name = "";
		        } else {
		            $user_last_name = "";
		        }
		        if( isset( $results_guest[0]->phone ) ) {
		            $phone = $results_guest[0]->phone;
		        } elseif ( $value->user_id == "0" ) {
		            $phone = '';
		        } else {
		            $phone = '';
		        }
		    } else {
		        $user_email_biiling = get_user_meta( $user_id, 'billing_email', true );
		        $user_email = __( "User Deleted" , "xcart-tr" );
		        if( isset( $user_email_biiling ) && "" == $user_email_biiling ) {
		            $user_data  = get_userdata( $user_id );
		            if( isset( $user_data->user_email ) && "" != $user_data->user_email ) {
		            	$user_email = $user_data->user_email;
		        	} 
		        } else if ( '' != $user_email_biiling ) {
		            $user_email = $user_email_biiling;
		        }
		        $user_first_name_temp = get_user_meta( $user_id, 'billing_first_name', true );
		        if( isset( $user_first_name_temp ) && "" == $user_first_name_temp ) {
		            $user_data  = get_userdata( $user_id );
		            if( isset( $user_data->first_name ) && "" != $user_data->first_name ) {
		            	$user_first_name = $user_data->first_name;
		            }  
		        } else {
		            $user_first_name = $user_first_name_temp;
		        }
		        $user_last_name_temp = get_user_meta( $user_id, 'billing_last_name', true );
		        if( isset( $user_last_name_temp ) && "" == $user_last_name_temp ) {
		            $user_data  = get_userdata( $user_id );
		            if( isset( $user_data->last_name ) && "" != $user_data->last_name ) {
		            	$user_last_name = $user_data->last_name;
		            }   
		        } else {
		            $user_last_name = $user_last_name_temp;
		        }
		        $user_phone_number = get_user_meta( $value->user_id, 'billing_phone' );
		        if( isset( $user_phone_number[0] ) ) {
		            $phone = $user_phone_number[0];
		        } else {
		            $phone = "";
		        }
		    }
		    $cart_info        = json_decode( $value->abandoned_cart_info );
		    $order_date       = "";
		    $cart_update_time = $value->abandoned_cart_time;

		    if( $cart_update_time != "" && $cart_update_time != 0 ) {
		        $date_format = date_i18n( get_option( 'date_format' ), $cart_update_time );
                $time_format = date_i18n( get_option( 'time_format' ), $cart_update_time );
                $order_date  = $date_format . ' ' . $time_format;
		    }

		    if( "GUEST" == $value->user_type ) {
                $ac_cutoff_time = is_numeric( get_option( 'ac_cart_abandoned_time_guest', 10 ) ) ? get_option( 'ac_cart_abandoned_time_guest', 10 ) : 10;
		    }else{
		        $ac_cutoff_time = is_numeric( get_option( 'ac_cart_abandoned_time', 10 ) ) ? get_option( 'ac_cart_abandoned_time', 10 ) : 10;
		    }
		    $cut_off_time   = $ac_cutoff_time * 60;
		    $current_time   = current_time( 'timestamp' );
		    $compare_time   = $current_time - $cart_update_time;
		    $cart_details   = new stdClass();
		    $line_total     = 0;
		    $cart_total     = $item_subtotal = $item_total = $line_subtotal_tax_display =  $after_item_subtotal = $after_item_subtotal_display = 0;
            $line_subtotal_tax = 0;
            $xorgcore_include_tax = get_option( 'woocommerce_prices_include_tax' );
            $xorgcore_include_tax_setting = get_option( 'woocommerce_calc_taxes' );

		    if( isset( $cart_info->cart ) ) {
		        $cart_details = $cart_info->cart;
		    }
		    $quantity_total = 0;
		    if( ( is_object( $cart_details ) && count( get_object_vars( $cart_details ) ) > 0 ) || ( is_array( $cart_details ) && count( $cart_details ) > 0 ) ) {
    	        foreach( $cart_details as $k => $v ) {

    	        	if( version_compare( $woocommerce->version, '3.0.0', ">=" ) ) {
                      $xorgcore_product   = wc_get_product($v->product_id );
                      $product        = wc_get_product($v->product_id );
                    }else {
                        $product      = get_product( $v->product_id );
                        $xorgcore_product = get_product($v->product_id );
                    }
                    if ( false !== $product ) {
	    	            if( isset($xorgcore_include_tax) && $xorgcore_include_tax == 'no' && isset($xorgcore_include_tax_setting) && $xorgcore_include_tax_setting == 'yes' ) {
	                        //$item_subtotal = $item_subtotal + $v->line_total;  
	                        $line_total    = $line_total + $v->line_total;
	                        $line_subtotal_tax += $v->line_tax; 
	                    }else if ( isset($xorgcore_include_tax) && $xorgcore_include_tax == 'yes' &&
	                        isset($xorgcore_include_tax_setting) && $xorgcore_include_tax_setting == 'yes' ) {
	                        
	                        if( $v->line_tax != 0 && $v->line_tax > 0 ) {
								$line_subtotal_tax_display += $v->line_tax;
	                            
	                            $after_item_subtotal = $item_subtotal + $v->line_total + $v->line_tax;
								
								$item_subtotal = $item_subtotal + $v->line_subtotal + $v->line_subtotal_tax;
								$line_total    = $line_total +   $v->line_subtotal + $v->line_subtotal_tax;
	                        } else {
	                            $item_subtotal = $item_subtotal + $v->line_total;
	                            $line_total    = $line_total +  $v->line_total;
	                            $line_subtotal_tax_display += $v->line_tax;
	                        }
	                    }else{
	                    	$line_total = $line_total + $v->line_total;
	                    }
	                    $quantity_total = $quantity_total + $v->quantity;
                	}
    	        }
		    }
		    $line_total     = apply_filters ( 'acfac_change_currency', wc_price( $line_total ), $abandoned_order_id, $line_total, 'xorgcore_order_trash' );
		    $show_taxes = apply_filters('xorgcore_show_taxes', true);
		    if( $show_taxes && isset($xorgcore_include_tax) && $xorgcore_include_tax == 'no' && isset($xorgcore_include_tax_setting) && $xorgcore_include_tax_setting == 'yes' ) {
		    	//$line_subtotal_tax = wc_price( $line_subtotal_tax );
		    	$line_subtotal_tax     = apply_filters ( 'acfac_change_currency', wc_price( $line_subtotal_tax ), $abandoned_order_id, $line_subtotal_tax, 'xorgcore_order_trash' );
                $line_total = $line_total . '<br>'. __( "Tax: ", "xcart-tr" ) . $line_subtotal_tax;

            }else if( isset($xorgcore_include_tax) && $xorgcore_include_tax == 'yes' && isset($xorgcore_include_tax_setting) && $xorgcore_include_tax_setting == 'yes' ) {
            	//$line_subtotal_tax_display = wc_price( $line_subtotal_tax_display );
            	$line_subtotal_tax_display     = apply_filters ( 'acfac_change_currency', wc_price( $line_subtotal_tax_display ), $abandoned_order_id, $line_subtotal_tax_display, 'xorgcore_order_trash' );
                if ($show_taxes) {
                	$line_total = $line_total . ' (' . __( "includes Tax: " , "xcart-tr" ) . $line_subtotal_tax_display . ')';
            	} 
            	else {
            		$line_total = $line_total;
            	}
            }    
		    if( 1 == $quantity_total ) {
		        $item_disp = __( "item", "xcart-tr" );
		    } else {
		        $item_disp = __( "items", "xcart-tr" );
		    }
		    $coupon_details          = get_user_meta( $value->user_id, '_woocommerce_ac_coupon', true );
		    $coupon_detail_post_meta = xorgcore_Common::xorgcore_get_coupon_post_meta( $value->id );
		    
		    if( $value->unsubscribe_link == 1 ) {
		        $ac_status = __( "لغو اشتراک", "xcart-tr" );
		        $ac_status = "<span id ='xorgcore_unsubscribe_link' class = 'unsubscribe_link'  >" . $ac_status . "</span>";
		    } elseif( $value->cart_ignored == 0 && $value->recovered_cart == 0 ) {
		        $ac_status = __( "رها شده", "xcart-tr" );
		        $ac_status = "<span id ='xorgcore_abandoned_new' class = 'xorgcore_abandoned_new'  >" . $ac_status . "</span>";
		    } elseif ( $value->cart_ignored == 1 && $value->recovered_cart == 0 ) {
		        $ac_status = __( "رها شده اما <br> یک سبد خرید جدید توسط مشتری ایجاد شده.", "xcart-tr" );
		        $ac_status = "<span id ='xorgcore_abandoned_new' class = 'xorgcore_abandoned_new'  >" . $ac_status . "</span>";
		    } elseif ( $value->cart_ignored == 4 && $value->recovered_cart == 0 ) {
		        $ac_status = __( "رها شده - در انتظار پرداخت (رفته تو بانک پرداخت کنه، کنسل شده)", "xcart-tr" );
		        $ac_status = "<span id ='xorgcore_abandoned_unpaid' class = 'xorgcore_abandoned_unpaid'  >" . $ac_status . "</span>";
		    } elseif ( $value->cart_ignored == 2 && $value->recovered_cart == 0 ) {
		        $ac_status = __( "رها شده - لغو شده در صفحه پرداخت بانک", "xcart-tr" );
		        $ac_status = "<span id ='xorgcore_abandoned_cancelled' class = 'xorgcore_abandoned_cancelled'  >" . $ac_status . "</span>";
		    } elseif ( $value->cart_ignored == 1 && $value->recovered_cart > 0 ) {
		        $ac_status = __( "بازیابی شد :)", "xcart-tr" );
		        $ac_status = "<span id ='xorgcore_abandoned' class = 'xorgcore_abandoned'  >" . $ac_status . "</span>";
		    } elseif ( $value->cart_ignored == 3 && $value->recovered_cart == 0 ) {
		        $ac_status = __( "رها شده - ولی سفارشات رو ثبت کرده.", "xcart-tr" );
		        $ac_status = "<span id ='xorgcore_abandoned_received' class = 'xorgcore_abandoned_received'  >" . $ac_status . "</span>";
		    } else {
		        $ac_status = "";
		    }

		    $coupon_code_used = $coupon_code_message = "";
		    if ( $compare_time > $cut_off_time && $ac_status != "" ) {
		        $return_abandoned_orders[$i] = new stdClass();
                if( $quantity_total > 0 ) {
                    $abandoned_order_id                         = $abandoned_order_id;
                    $customer_information                       = $user_first_name . " ".$user_last_name;
                    $return_abandoned_orders[ $i ]->id          = $abandoned_order_id;
                    $return_abandoned_orders[ $i ]->email       = $user_email;
                    if( $phone == '' ) {
                        $return_abandoned_orders[ $i ]->customer    = $customer_information;
                    } else {
                        $return_abandoned_orders[ $i ]->customer    = $customer_information . "<br>" . $phone;
                    }
                    $return_abandoned_orders[ $i ]->order_total = $line_total . "<br>" . $quantity_total . " " . $item_disp;;
                    $return_abandoned_orders[ $i ]->quantity    = $quantity_total . " " . $item_disp;
                    $return_abandoned_orders[ $i ]->date        = $order_date;
                    $return_abandoned_orders[ $i ]->status      = $ac_status;
                    $return_abandoned_orders[ $i ]->user_id     = $user_id;

                    if( $display_tracked_coupons == 'on' ) {
						if( is_array( $coupon_detail_post_meta ) && count( $coupon_detail_post_meta ) > 0 ) {
							foreach( $coupon_detail_post_meta as $key => $value ) {
								if( '' !== $key ) {
									$coupon_code_used .= $key . "</br>";
									$coupon_code_message .= $value . "</br>";
								}
							}
							$return_abandoned_orders[ $i ]->coupon_code_used = $coupon_code_used;
							$return_abandoned_orders[ $i ]->coupon_code_status = $coupon_code_message;
						}
                    }
                } else {
                   $abandoned_order_id                    = $abandoned_order_id;
                   $return_abandoned_orders[ $i ]->id     = $abandoned_order_id;
                   $return_abandoned_orders[ $i ]->date   = $order_date;
                   $return_abandoned_orders[ $i ]->status = $ac_status;
                }
                $i++;
            }
		}
		
    	 if( isset( $_GET['orderby'] ) && $_GET['orderby'] == 'date' ) {
    	     if( isset( $_GET['order'] ) && $_GET['order'] == 'asc' ) {
    	         usort( $return_abandoned_orders, array( __CLASS__ , "xorgcore_class_order_date_asc" ) );
    	     } else {
    	         usort( $return_abandoned_orders, array( __CLASS__ , "xorgcore_class_order_date_dsc" ) );
    	     }
    	 } else if( isset( $_GET['orderby'] ) && $_GET['orderby'] == 'status' ) { 
    		if ( isset( $_GET['order'] ) && $_GET['order'] == 'asc' ) {
    			usort( $return_abandoned_orders, array( __CLASS__ , "xorgcore_class_status_asc" ) );
    		} else {
    			usort( $return_abandoned_orders, array( __CLASS__ , "xorgcore_class_status_dsc" ) );
    		}
    	}

    	return apply_filters( 'xorgcore_abandoned_orders_table_data', $return_abandoned_orders );
    }

    
    function xorgcore_class_order_date_asc( $value1,$value2 ) {
	   if( isset( $value1->date ) && isset( $value2->date ) ) {
    	    $date_two           = $date_one = '';
    	    $value_one          = $value1->date;
    	    $value_two          = $value2->date;
    	    $date_formatted_one = date_create_from_format( 'd M, Y h:i A', $value_one );
    	    $date_formatted_two = date_create_from_format( 'd M, Y h:i A', $value_two );
    	    if( isset( $date_formatted_one ) && $date_formatted_one != '' ) {
    	        $date_one = date_format( $date_formatted_one, 'Y-m-d h:i A' );
    	    }
    	    if( isset( $date_formatted_two ) && $date_formatted_two != '' ) {
    	        $date_two = date_format( $date_formatted_two, 'Y-m-d h:i A' );
    	    }
    	    return strtotime($date_one) - strtotime($date_two);
	    } else {
	        return 1;
	    }
	}

	
	function xorgcore_class_order_date_dsc( $value1,$value2 ) {
	   if( isset( $value1->date ) && isset( $value2->date ) ) {
    	    $date_two            = $date_one = '';
    	    $value_one           = $value1->date;
    	    $value_two           = $value2->date;
    	    $date_formatted_one  = date_create_from_format( 'd M, Y h:i A', $value_one );
    	    $date_formatted_two  = date_create_from_format( 'd M, Y h:i A', $value_two );
    	    if( isset( $date_formatted_one ) && $date_formatted_one != '' ) {
    	        $date_one = date_format( $date_formatted_one, 'Y-m-d h:i A' );
    	    }
    	    if( isset( $date_formatted_two ) && $date_formatted_two != '' ) {
    	        $date_two = date_format( $date_formatted_two, 'Y-m-d h:i A' );
    	    }
    	    return strtotime( $date_two ) - strtotime( $date_one );
	    } else {
	        return 1;
	    };
	}

	
	function xorgcore_class_status_asc( $value1,$value2 ) {
	    return strcasecmp( $value1->status,$value2->status );
	}

	
	function xorgcore_class_status_dsc ( $value1,$value2 ) {
	    return strcasecmp( $value2->status,$value1->status );
	}
	

	public function column_default( $xorgcore_abandoned_orders, $column_name ) {
	    $value = '';
	    switch ( $column_name ) {
	        case 'id' :
			    if( isset( $xorgcore_abandoned_orders->id ) ) {

					$xorgcore_array = array(
								'action' => 'xorgcore_abandoned_cart_info',
								'cart_id' => $xorgcore_abandoned_orders->id
					    	);
		            	$xorgcore_url = add_query_arg(
		            					$xorgcore_array , admin_url( 'admin-ajax.php' )
	            					);

					$value =  '<strong> <a class="xorgcore-js-open-modal" data-xorgcore-cart-id="'.$xorgcore_abandoned_orders->id.'" data-modal-type="ajax" href="' . $xorgcore_url . '">'.$xorgcore_abandoned_orders->id.'</a> </strong>' ;
			    }
				break;
			case 'customer' :
			    if( isset( $xorgcore_abandoned_orders->customer ) ) {

			        $user_role = '';
			        if ( $xorgcore_abandoned_orders->user_id == 0 ) {
			            $user_role = 'کاربر مهمان';
			        }
			        elseif ( $xorgcore_abandoned_orders->user_id >= 63000000 ) {
			            $user_role = 'کاربر مهمان';
			        }else{
			            $user_role = xorgcore_Common::xorgcore_get_user_role ( $xorgcore_abandoned_orders->user_id );

			        }
			        $value = $xorgcore_abandoned_orders->customer . "<br>" .$user_role;
			    }
				break;
			case 'order_total' :
			    if( isset( $xorgcore_abandoned_orders->order_total ) ) {
			       $value = $xorgcore_abandoned_orders->order_total;
			    }
				break;
			case 'quantity' :
			    if( isset( $xorgcore_abandoned_orders->quantity ) ) {
			       $value = $xorgcore_abandoned_orders->quantity;
			    }
				break;
			case 'date' :
			    if( isset( $xorgcore_abandoned_orders->date ) ) {
	 			   $value = $xorgcore_abandoned_orders->date;
			    }
				break;
			case 'status' :
			    if( isset( $xorgcore_abandoned_orders->status ) ) {
			     $value = $xorgcore_abandoned_orders->status;
			    }
			    break;
		    case 'coupon_code_used' :
		        if( isset( $xorgcore_abandoned_orders->coupon_code_used ) ) {
		            $value = $xorgcore_abandoned_orders->coupon_code_used;
		        }
		        break;
	        case 'coupon_code_status' :
	            if( isset( $xorgcore_abandoned_orders->coupon_code_status ) ) {
	                $value = $xorgcore_abandoned_orders->coupon_code_status;
	            }
	            break;

            case 'xorgcore_actions' :
	            if( isset( $xorgcore_abandoned_orders->id ) ) {

		            $xorgcore_array = array(
								'action' => 'xorgcore_abandoned_cart_info',
								'cart_id' => $xorgcore_abandoned_orders->id
					    	);
		            	$xorgcore_url = add_query_arg(
		            					$xorgcore_array , admin_url( 'admin-ajax.php' )
	            					);

					$value =  '<a oncontextmenu="return false;" class="button tips view xorgcore-button-icon xorgcore-js-open-modal" data-tip= "View" data-modal-type="ajax" data-xorgcore-cart-id="'.$xorgcore_abandoned_orders->id.'" href="' . $xorgcore_url . '">View</a>';
	            }
	            break;
            case 'email_captured_by':
            	if( isset( $xorgcore_abandoned_orders->id ) && isset( $xorgcore_abandoned_orders->user_id ) ) {
            		$value = '';
            		if ( $xorgcore_abandoned_orders->user_id > 0 ){
	            		$xorgcore_cart_popup_data = get_post_meta ( $xorgcore_abandoned_orders->id, 'xorgcore_atc_report' );
	            		//if ( ) $xorgcore_cart_popup_data[0]['xorgcore_atc_action']
	            		if ( count( $xorgcore_cart_popup_data ) > 0 ){
	            			//var_dump( $xorgcore_cart_popup_data);
	            			$xorgcore_user_selected_action = $xorgcore_cart_popup_data[0]['xorgcore_atc_action'];
	            			if ( 'yes' == $xorgcore_user_selected_action ){
	            			$value = __( 'پاپ آپ', 'xcart-tr' );
	            			}else if ( 'no' == $xorgcore_user_selected_action ) {
	            				$value = __( 'Checkout صفحه', 'xcart-tr' );
	            			}
	            		}else{
	            			if ( $xorgcore_abandoned_orders->user_id >= 63000000 ) {
	            				$value = __( 'صفحه Checkout', 'xcart-tr' );
	            			}else if ( $xorgcore_abandoned_orders->user_id > 0 &&  $xorgcore_abandoned_orders->user_id < 63000000 ) {
	            				$value = __( 'پروفایل کاربر', 'xcart-tr' );
	            			}

	            		}
            		}
            	}
			break;
			default :
				$value = isset( $xorgcore_abandoned_orders->$column_name ) ? $xorgcore_abandoned_orders->$column_name : '';
				break;
	    }
		return apply_filters( 'xorgcore_abandoned_orders_column_default', $value, $xorgcore_abandoned_orders, $column_name );
	}
	
	public function get_bulk_actions() {
	    return array(
	    	'xorgcore_abandoned_restore'       => __( 'بازیابی', 'xcart-tr' ),
	        'xorgcore_abandoned_delete'       => __( 'حذف موقت', 'xcart-tr' )

	    );
	}

	
	protected function extra_tablenav( $which ) {
		if ( isset( $this->total_count ) && $this->total_count > 0 ) {
			?>
			<button type="submit" name="xorgcore-trash-all" class="button-secondary" value="xorgcore-trash-all"><?php echo esc_attr__( 'خالی کردن', 'xcart-tr' ); ?></button>
			<?php
		}
	}
}
?>
