<?php


if ( ! defined( 'ABSPATH' ) ) exit;


class xorgcore_Dashboard_Widget_Heartbeat {

	
	public static function xorgcore_init() {
		add_filter( 'heartbeat_received',     array( 'xorgcore_Dashboard_Widget_Heartbeat' , 'xorgcore_heartbeat' ), 10, 2 );
		add_action( 'admin_enqueue_scripts',  array( 'xorgcore_Dashboard_Widget_Heartbeat' , 'xorgcore_enqueue_scripts' ) );
	}

	
	public static function xorgcore_heartbeat( $response, $data ) {
		if( ! current_user_can( 'manage_woocommerce' ) ) {
			return $response; 
		}
		
		if( ( isset( $data['xorgcore_widget_heartbeat'] ) ) && ( $data['xorgcore_widget_heartbeat'] == 'xorgcore_widget_summary' ) ) {
			
			$reports = new xorgcore_Dashboard_Widget_Report();
            
			$response['xorgcore-total-recover']   = $reports->get_total_reports( 'recover' );
			$response['xorgcore-total-abandoned'] = $reports->get_total_reports( 'abandoned' );
			$response['xorgcore-month-recover']   = $reports->get_this_month_reports( 'recover' );
			$response['xorgcore-month-abandoned'] = $reports->get_this_month_reports( 'abandoned' );
			$response['xorgcore-today-recover']   = $reports->get_today_reports( 'recover' );
			$response['xorgcore-today-abandoned'] = $reports->get_today_reports( 'abandoned' );
			$today_ratio                      = $reports->get_today_reports( 'ratio' );
			$response['xorgcore-today-ratio']     = round ( $today_ratio, wc_get_price_decimals() ).'%';
			$month_ratio                      = $reports->get_this_month_reports( 'ratio' );
			$response['xorgcore-month-ratio']     = round ( $month_ratio, wc_get_price_decimals() ).'%';
			$total_ratio                      = $reports->get_total_reports( 'ratio' );
			$response['xorgcore-total-ratio']     = round ( $total_ratio, wc_get_price_decimals() ).'%';
		}
        return $response;
    }

	
	public static function xorgcore_enqueue_scripts() {
		if( ! current_user_can( 'manage_woocommerce' ) ) {
			return; 
		}
		
		wp_enqueue_script( 'heartbeat' );
		add_action( 'admin_print_footer_scripts', array( 'xorgcore_Dashboard_Widget_Heartbeat' , 'xorgcore_footer_js' ), 20 );
	}

	
	public static function xorgcore_footer_js() {
		global $pagenow;
		
		if( 'index.php' != $pagenow ) {
			return;
		}

		if( ! current_user_can( 'manage_woocommerce' ) ) {
			return; 
		}
		?>
		<script>
			(function($){
				
				$(document).on('heartbeat-send', function(e, data) {
					data['xorgcore_widget_heartbeat'] = 'xorgcore_widget_summary';
				});

				
				$(document).on( 'heartbeat-tick', function(e, data) {

					
					if ( ! data['xorgcore-total-abandoned'] )
						return;

					<?php if ( defined( 'WP_DEBUG' ) && WP_DEBUG ) : ?>
					//console.log('tick');
					<?php endif; ?>

					
					xorgcore_update_heartbeat( '.xorgcore_dashboard_report_widget .table_totals .xorgcore.b-earnings',      data['xorgcore-total-abandoned'] );
					xorgcore_update_heartbeat( '.xorgcore_dashboard_report_widget .table_totals .xorgcore.b-sales',         data['xorgcore-total-recover'] );
					xorgcore_update_heartbeat( '.xorgcore_dashboard_report_widget .table_today .xorgcore.b-earnings',       data['xorgcore-today-abandoned'] );
					xorgcore_update_heartbeat( '.xorgcore_dashboard_report_widget .table_today .xorgcore.b-sales',          data['xorgcore-today-recover'] );
					xorgcore_update_heartbeat( '.xorgcore_dashboard_report_widget .table_current_month .b-earnings',    data['xorgcore-month-abandoned'] );
					xorgcore_update_heartbeat( '.xorgcore_dashboard_report_widget .table_current_month .b-sales',       data['xorgcore-month-recover'] );

					xorgcore_update_heartbeat( '.xorgcore_dashboard_report_widget .table_current_month .b-sales-ratio', data['xorgcore-month-ratio'] );
					xorgcore_update_heartbeat( '.xorgcore_dashboard_report_widget .table_today .xorgcore.b-sales-ratio',    data['xorgcore-today-ratio'] );
					xorgcore_update_heartbeat( '.xorgcore_dashboard_report_widget .table_totals .xorgcore.b-sales-ratio',   data['xorgcore-total-ratio'] );

					
					setTimeout(function(){
						$('.xorgcore_dashboard_report_widget .xorgcore.b-sales,.xorgcore_dashboard_report_widget .xorgcore.b-earnings').css( 'font-weight', 'normal' );
						$('.xorgcore_dashboard_report_widget .table_current_month .xorgcore.b-earnings,.xorgcore_dashboard_report_widget .table_current_month .xorgcore.b-sales, .xorgcore_dashboard_report_widget .table_current_month .xorgcore.b-sales-ratio, .xorgcore_dashboard_report_widget .table_today .xorgcore.b-sales-ratio, .xorgcore_dashboard_report_widget .table_totals .xorgcore.b-sales-ratio').css( 'font-weight', 'normal' );
					}, 2000);

				});

				function xorgcore_update_heartbeat( selector, new_value ) {
					var current_value       = $(selector).text();
					current_value           = current_value.replace(/ /g, '');

				    var new_value_to_string = new_value.toString();
					new_value_to_string     = new_value_to_string.replace(/ /g, '');

					$(selector).text( new_value_to_string );

				    if ( current_value !== new_value_to_string ) {
						$(selector).css( 'font-weight', 'bold' );
					}
				}
			}(jQuery));
		</script>
		<?php
	}
}
//add_action( 'plugins_loaded', array( 'xorgcore_Dashboard_Widget_Heartbeat' , 'xorgcore_init' ) );
