<?php 


if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class xorgcore_SMS_Templates extends WP_List_Table {

	
	public $per_page = 20;

	
	public $base_url;

	
	public $total_count;

    
	public function __construct() {

		
		parent::__construct( array(
	        'singular' => __( 'sms_template_id', 'xcart-tr' ), //singular name of the listed records
	        'plural'   => __( 'sms_template_ids', 'xcart-tr' ), //plural name of the listed records
			'ajax'      => true             			
		) );
		$this->xorgcore_get_sms_templates_count();
		$this->process_bulk_action();
        $this->base_url = admin_url( 'admin.php?page=xcart&action=cart_recovery&section=sms' );
	}
	
	public function xorgcore_sms_templates_prepare_items() {

		$columns               = $this->get_columns();
		$hidden                = $this->xorgcore_hidden_sms_cols();
		$sortable              = array();
		$data                  = $this->xorgcore_sms_templates();		
		$this->_column_headers = array( $columns, $hidden, $sortable);
		$total_items           = $this->total_count;
		$this->items           = $data;
		
		$this->set_pagination_args( array(
				'total_items' => $total_items,                  	
				'per_page'    => $this->per_page,                     	
				'total_pages' => ceil( $total_items / $this->per_page )   
		      )
		);
	}
	
	function xorgcore_hidden_sms_cols() {
	    return ( apply_filters( 'xorgcore_sms_hidden_cols', array( 'updated', 'full_txt_msg', 'sms_sent' ) ) );
	}
	
	public function get_columns() {
	    
        $columns = array(
            'cb'                  => '<input type="checkbox" />',
            'id'                  => __( 'آی‌دی', 'xcart-tr' ),
            'updated'             => __( 'Updated', 'xcart-tr' ),
            'txt_msg'             => __( 'متن پیام', 'xcart-tr' ),
            'full_txt_msg'        => __( 'Complete Message', 'xcart-tr' ),
            'coupon_code'         => __( 'کد تخفیف', 'xcart-tr' ),
        	'sent_time'     	  => __( 'زمان ارسال', 'xcart-tr' ),
        	'sms_sent'  	      => __( 'Messages Sent', 'xcart-tr' ),
        	'activate'  		  => __( 'شروع ارسال', 'xcart-tr' ),
            'actions'             => __( 'حذف', 'xcart-tr' )
        );
		return apply_filters( 'xorgcore_sms_templates_col', $columns );
	}
	
	
	function column_cb( $item ){
	    
	    $template_id = '';
	    if( isset( $item->id ) && "" != $item->id ){
	       $template_id = $item->id; 
	    }
	    return sprintf(
	        '<input type="checkbox" name="%1$s[]" value="%2$s" />',
	        'template_id',
	        $template_id
	    );
	}

	
	public function xorgcore_sms_templates() { 
    	global $wpdb;    	
    	
    	$return_templates_data = array();
    	
    	
    	$sms_query = "SELECT * FROM " . xorgcore_NOTIFICATIONS . "
    	               WHERE type = %s";
    	$sms_list = $wpdb->get_results( $wpdb->prepare( $sms_query, 'sms' ) );
    	
    	$template_count = 0;
    	if( is_array( $sms_list ) && count( $sms_list ) > 0 && false !== $sms_list ) {
            foreach( $sms_list as $sms_details ) {
                
                $template_id = $sms_details->id;
                
                
                $return_templates_data[ $template_count ] = new stdClass();
                
                $return_templates_data[ $template_count ]->id = $template_id;
                
                $return_templates_data[ $template_count ]->updated = 0;
                 
                
                $return_templates_data[ $template_count ]->full_txt_msg = $sms_details->body;

                
                $return_templates_data[ $template_count ]->coupon_code = $sms_details->coupon_code;
                
                $return_templates_data[ $template_count ]->sent_time = $sms_details->frequency;
                $return_templates_data[ $template_count ]->sms_sent = 0;
                $return_templates_data[ $template_count ]->active = $sms_details->is_active == 1 ? 'on' : 'off';
                $template_count++;
            }
        	
    	}
    	
        return apply_filters( 'xorgcore_sms_templates_data', $return_templates_data );
        
	}
	
	public function column_default( $xorgcore_sms_list, $column_name ) {
	    $value = '';
	    
	    switch ( $column_name ) {	       
	        	            
			case 'activate' :
			    if( isset( $xorgcore_sms_list->active ) ) {			       
			       $id        = $xorgcore_sms_list->id;
			       $active = $xorgcore_sms_list->active;
		
			       $active_text   = __( $active, 'xcart-tr' ); 
			       $value =  "<button type='button' class='xorgcore-switch xorgcore-toggle-template-status' " 
					. "xorgcore-sms-id='$id' "
					. "xorgcore-template-switch='" . ( $active ) . "'>"
					. $active_text . '</button>'; 
			       
			    }
			    
				break;	

			case 'txt_msg':
			    
			    $sms_id = $xorgcore_sms_list->id;
			    
			    
			    if( isset( $xorgcore_sms_list->full_txt_msg ) && '' !== $xorgcore_sms_list->full_txt_msg ) {
			        
			        $truncated_msg = substr( $xorgcore_sms_list->full_txt_msg, 0, 30 );
			        $msg_link = "<a id='sms_txt_$sms_id' href='javascript:void(0)'>$truncated_msg...</a>";
			    } else {
			        $msg_link = '';
			    }
			        
		        $value = $msg_link;
			    
			    break;

			case 'coupon_code':
			    $id        = $xorgcore_sms_list->id;
			    $value = "
                <div id='coupon_options' class='panel'>
                    <div class='options_group'>
                        <p class='form-field' style='padding-left:0px !important;'>";
			    
			    $json_ids       = array();
			    $coupon_ids     = array();
			    $coupon_code_id = ( isset( $xorgcore_sms_list->coupon_code ) ) ? $xorgcore_sms_list->coupon_code : '';
			    
			    if ( $coupon_code_id > 0 ) {
			        
                    $product = get_the_title( $coupon_code_id );
                    $json_ids[ $coupon_code_id ] = $product ;
                
			    }
			    
			    if( version_compare( WOOCOMMERCE_VERSION, "3.0.0" ) > 0 ) {
			        $value .= "
                    <select id='coupon_ids_$id' name='coupon_ids[]' class='wc-coupon-search wc-product-search' style='width: 100%;' data-placeholder='" . esc_attr__( 'جستجتو برای کد تخفیف&hellip;', 'woocommerce' ) . "' data-action='xorgcore_json_find_coupons' multiple='multiple'>";
                            if ( $coupon_code_id > 0  ) {
                                $coupon = get_the_title( $coupon_code_id );
                                $value .= "<option value='" . esc_attr( $coupon_code_id ) . "'" . selected( true, true, false ) . ">" . wp_kses_post( $coupon ) . "</option>";
                            }
                        
                    $value .= "</select>";
                } else {
                    $value .= "
                    <input type='hidden' id='coupon_ids_$id' name='coupon_ids[]' class='wc-coupon-search wc-product-search' style='width: 100%;' data-placeholder='" . esc_attr__( 'جستجو برای کد تخفیف&hellip;', 'woocommerce' ) ."' data-action='xorgcore_json_find_coupons'
                       data-selected='" . esc_attr( json_encode( $json_ids ) ) . "' value='" . implode( ',', array_keys( $json_ids ) ) . "'
                    />";
                }
                
                $value .= "</p></div></div>";
                 
			    break;
			case 'sent_time':
			    $sms_id = $xorgcore_sms_list->id;
			    
			    $freq = $xorgcore_sms_list->sent_time;
			    
			    $min_loop = 59;
			    $hour_loop = 23;
			    $day_loop = 90;
			     
			    $freq_split = explode( ' ', $freq );
			    
			    $frequency_numeric = $freq_split[0];
			    $frequency_value = isset( $freq_split[1] ) ? $freq_split[1] : 'minutes';
			    
			    switch( strtolower( $frequency_value ) ) {
			        case '':
			        case 'minutes':
			            $count = $min_loop;
			            break;
			        case 'hours':
			            $count = $hour_loop;
			            break;
			        case 'days':
			            $count = $day_loop;
			            break;
			    }
			     
			    $select_count = "<select id='freq_count_$sms_id'>";
			    for( $i = 0; $i <= $count; $i++ ) {
			        $select_count .= ( $frequency_numeric == $i ) ? "<option value='$i' selected>$i</option>" : "<option value='$i'>$i</option>";
			    }
			    $select_count .= '</select>';
			     
			    $select_freq = "<select id='freq_value_$sms_id'>";
			     
			    $value_array = array( 'minutes' => __( 'دقیقه', 'xcart-tr' ),
			                          'hours'   => __( 'ساعت', 'xcart-tr' ),
			                          'days'    => __( 'روز', 'xcart-tr' ) 
			     );
			    
			    foreach( $value_array as $k => $v ) {
			        $select_freq .= ( strtolower( $frequency_value ) == $k ) ? "<option value='$k' selected>$v</option>" : "<option value='$k'>$v</option>"; 
			    }

                $select_freq .= "</select>";
			     
			    $value = "$select_count &nbsp; $select_freq &nbsp; " . __( 'پس از ثبت سفارش رها شده', 'xcart-tr' );
			     
			     break;
			case 'actions':
			    $sms_id = $xorgcore_sms_list->id;
			    $value = "<a href='javascript:void(0)' id='delete_$sms_id' class='delete_sms' ><i class='fa fa-trash-o fa-2x'></i></a>";
			    break;
			default:			    
				$value = isset( $xorgcore_sms_list->$column_name ) ? $xorgcore_sms_list->$column_name : '';
				break;
	    }		
		return apply_filters( 'xorgcore_sms_template_column_default', $value, $xorgcore_sms_list, $column_name );
	}
	
	
	public function get_bulk_actions() {
	    return array(
	        'xorgcore_delete_sms_template' => __( 'Delete', 'xcart-tr' )
	    );
	}
	
	
	function extra_tablenav( $which ) {
	    ?>
	    <input type='button' class='sms_bulk_save button-primary alignright' value='<?php _e( 'ذخیره', 'xcart-tr' ); ?>' /> 
	    <?php 
	}
	
	
	function display_rows() {
	    
	    
	    $records = $this->items;
	    
	    
	    list( $columns, $hidden ) = $this->get_column_info();
	    
	    
	    if( !empty( $records ) ) {
	        foreach($records as $rec){
	    
    	        
    	        echo '<tr id="sms_'.$rec->id.'">';
    	        foreach ( $columns as $column_name => $column_display_name ) {
    	    
    	            
    	            $class = "class='$column_name column-$column_name'";
    	            $style = "";
    	            if ( in_array( $column_name, $hidden ) ) $style = ' style="display:none;"';
    	            $attributes = $class . $style;
    	    
    	            
    	            switch ( $column_name ) {
    	                case "cb":
    	                    echo '<th scope="row" class="check-column">';
				            echo $this->column_cb( $rec );
				            echo '</th>';
    	                    break;
    	                case "id":  
    	                    echo "<td $attributes>";
    	                    echo $this->column_default( $rec, $column_name ) . '</td>';   
    	                    break;
    	                case "updated":
    	                    echo "<td $attributes>";
    	                    echo $this->column_default( $rec, $column_name ) . '</td>';
    	                    break;
    	                case "txt_msg": 
    	                    echo "<td $attributes>";
    	                    echo $this->column_default( $rec, $column_name ) . '</td>'; 
    	                    break;
    	                case "full_txt_msg": 
    	                    echo "<td $attributes>";
    	                    echo $this->column_default( $rec, $column_name ) . '</td>'; 
    	                    break;
    	                case 'coupon_code':
    	                    echo "<td $attributes>";
    	                    echo $this->column_default( $rec, $column_name ) . '</td>';
    	                    break;
    	                case "sent_time": 
    	                    echo "<td $attributes>";
    	                    echo $this->column_default( $rec, $column_name ) . '</td>'; 
    	                    break;
    	                case "sms_sent": 
    	                    echo "<td $attributes>";
    	                    echo $this->column_default( $rec, $column_name ) . '</td>'; 
    	                    break;
    	                case "activate": 
    	                    echo "<td $attributes>";
    	                    echo $this->column_default( $rec, $column_name ) .'</td>'; 
    	                    break;
	                    case "actions":
	                        echo "<td $attributes>";
	                        echo $this->column_default( $rec, $column_name ) . '</td>';
	                        break;
    	            }
    	        }
    	    
    	        
    	        echo'</tr>';
            }
	    }
	}  
}
?>