<?php 


if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class xorgcore_Templates_Table extends WP_List_Table {

	
	public $per_page = 30;

	
	public $base_url;

	
	public $total_count;

    
	public function __construct() {

		
		parent::__construct( array(
	        'singular' => __( 'template_id', 'xcart-tr' ), //singular name of the listed records
	        'plural'   => __( 'template_ids', 'xcart-tr' ), //plural name of the listed records
			'ajax'      => false             			
		) );
		$this->xorgcore_get_templates_count();
		$this->process_bulk_action();
        $this->base_url = admin_url( 'admin.php?page=xcart&action=cart_recovery&section=emailtemplates' );
	}
	
	public function xorgcore_templates_prepare_items() {

		$columns               = $this->get_columns();
		$hidden                = array(); 
		$sortable              = $this->xorgcore_templates_get_sortable_columns();
		$data                  = $this->xorgcore_templates_data();		
		$this->_column_headers = array( $columns, $hidden, $sortable);
		$total_items           = $this->total_count;
		$this->items           = $data;
		
		$this->set_pagination_args( array(
				'total_items' => $total_items,                  	
				'per_page'    => $this->per_page,                     	
				'total_pages' => ceil( $total_items / $this->per_page )   
		      )
		);
	}
	
	public function get_columns() {
	    
        $columns = array(
            'cb'                  => '<input type="checkbox" />',
            'sr'                  => __( 'Sr', 'xcart-tr' ),
            'template_name'       => __( 'Name Of Template', 'xcart-tr' ),
        	'sent_time'     	  => __( 'Sent After Set Time', 'xcart-tr' ),
        	'template_filter'  	  => __( 'Send To Segment(s)', 'xcart-tr' ),
			'email_sent'  	      => __( 'Number of Emails Sent', 'xcart-tr' ),
			'open_rate'			  => __( 'Open Rate', 'xcart-tr' ),
			'link_rate'			  => __( 'Link Click Rate', 'xcart-tr' ),
			'coupon_rate'		  => __( 'Coupon Redemption Rate', 'xcart-tr' ),
        	'percentage_recovery' => __( 'Conversion Rate', 'xcart-tr' ),
        	'activate'  		  => __( 'Start Sending', 'xcart-tr' )
        );
		return apply_filters( 'xorgcore_templates_columns', $columns );
	}
	
	
	function column_cb( $item ){
	    
	    $template_id = '';
	    if( isset( $item->id ) && "" != $item->id ){
	       $template_id = $item->id; 
	    }
	    return sprintf(
	        '<input type="checkbox" name="%1$s[]" value="%2$s" />',
	        'template_id',
	        $template_id
	    );
	}
	
	public function xorgcore_templates_get_sortable_columns() {
		$columns = array(
			'template_name' => array( 'template_name', false ),
			'sent_time'		=> array( 'sent_time',false),
		);
		return apply_filters( 'xorgcore_templates_sortable_columns', $columns );
	}
	
	
	public function column_template_name( $template_row_info ) {	
	    $row_actions = array();
	    $value       = '';
	    $template_id = 0;
	    if( isset( $template_row_info->template_name ) ) {	    
		    $template_id           = $template_row_info->id ; 	    
		    $row_actions['edit']   = '<a href="' . wp_nonce_url( add_query_arg( array( 'action' => 'cart_recovery', 'section' => 'emailtemplates', 'mode'=>'edittemplate', 'id' => $template_row_info->id ), $this->base_url ), 'abandoned_order_nonce') . '">' . __( 'Edit', 'xcart-tr' ) . '</a>';
		    $row_actions['copy']   = '<a href="' . wp_nonce_url( add_query_arg( array( 'action' => 'cart_recovery', 'section' => 'emailtemplates', 'mode'=>'copytemplate', 'id' => $template_row_info->id ), $this->base_url ), 'abandoned_order_nonce') . '">' . __( 'Duplicate', 'xcart-tr' ) . '</a>';
		    $row_actions['delete'] = '<a href="' . wp_nonce_url( add_query_arg( array( 'action' => 'xorgcore_delete_template', 'template_id' => $template_row_info->id ), $this->base_url ), 'abandoned_order_nonce') . '">' . __( 'Delete', 'xcart-tr' ) . '</a>';	    
		    $email                 = $template_row_info->template_name;
	        $value                 = $email . $this->row_actions( $row_actions );	    
	    }	
	    return apply_filters( 'xorgcore_template_single_column', $value, $template_id, 'email' );
	}
    
	
    public function xorgcore_get_templates_count() {	
        global $wpdb;	
		$this->total_count = $wpdb->get_var( "SELECT COUNT(`id`) FROM `" .xorgcore_EMAIL_TEMPLATE_TABLE."`" );
    }
	
	public function xorgcore_templates_data() { 
    	global $wpdb;    	
    	$return_templates_data = array();
    	$per_page              = $this->per_page;
    	$results               = array();    	     
        $xorgcore_get_decimal      = wc_get_price_decimals();

    	$query                 = "SELECT id, is_active, frequency, day_or_hour, rules, template_name, body 
    							  FROM `" . xorgcore_EMAIL_TEMPLATE_TABLE . "` ORDER BY day_or_hour asc , frequency asc";
        $results               = $wpdb->get_results( $query );		
    
    	$i = 0;    	
    	$minute_seconds        = 60;
        $hour_seconds          = 3600; 
        $day_seconds           = 86400; 
		$time_to_send_template_after = '';
		
		
        $start_date_range = '';
        if( isset( $_POST[ 'start_date_cart_recovery' ] ) && '' !== $_POST[ 'start_date_cart_recovery' ] ) {
        	$start_date_range = sanitize_text_field( wp_unslash( $_POST[ 'start_date_cart_recovery' ] ) );
        }
		if( '' === $start_date_range && isset( $_SESSION[ 'start_date' ] ) && '' !== $_SESSION[ 'start_date' ] ) {
			$start_date_range = sanitize_text_field( wp_unslash( $_SESSION[ 'start_date' ] ) );
		}

        $end_date_range = '';
        if ( isset( $_POST[ 'end_date_cart_recovery' ] ) && '' !== $_POST[ 'end_date_cart_recovery' ] ) {
            $end_date_range = $_POST[ 'end_date_cart_recovery' ];
		}
		if( '' === $end_date_range && isset( $_SESSION[ 'end_date' ] ) && '' !== $_SESSION[ 'end_date' ] ) {
			$end_date_range = sanitize_text_field( wp_unslash( $_SESSION[ 'end_date' ] ) );
		}

        $start_date = date( 'Y-m-d H:i:s', strtotime( "$start_date_range 00:01:01" ) );
		$end_date   = date( 'Y-m-d H:i:s', strtotime( "$end_date_range 23:59:59" ) );

		$send_labels = array(
			'all'                       => __( 'All', 'xcart-tr' ),
			'registered_users'          => __( 'Registered Users', 'xcart-tr' ),
			'guest_users'               => __( 'Guest Users', 'xcart-tr' ),
			'xorgcore_email_customer'       => __( 'Customers', 'xcart-tr' ),
			'xorgcore_email_admin'          => __( 'Admin', 'xcart-tr' ),
			'xorgcore_email_customer_admin' => __( 'Customers & Admin', 'xcart-tr' ),
			'email_addresses'           => __( 'Email Addresses', 'xcart-tr' ),
		);
    	foreach( $results as $key => $value ) {    	    
    	    $return_templates_data[ $i ] = new stdClass();    	    
    	    $id                          = $value->id;
    	    $query_no_emails             = "SELECT COUNT(`id`) FROM " . xorgcore_EMAIL_SENT_HISTORY_TABLE . " WHERE template_id= %d AND sent_time >= %s AND sent_time <= %s";
    	    $ac_emails_count	         = $wpdb->get_var( $wpdb->prepare( $query_no_emails, $id, $start_date, $end_date ) );
			
			$query_no_recovers_test      = "SELECT COUNT(`id`) FROM " . xorgcore_EMAIL_SENT_HISTORY_TABLE . " WHERE recovered_order = '1' AND template_id = %d AND sent_time >= %s AND sent_time <= %s";
    	    $xorgcore_number_of_time_recover = $wpdb->get_var( $wpdb->prepare( $query_no_recovers_test, $id, $start_date, $end_date ) );

			$is_active   = $value->is_active;
    	
    	    $frequency   = $value->frequency;
    	    $day_or_hour = $value->day_or_hour;

    	    if( 'Minutes' == $value->day_or_hour ) {
                $time_to_send_template_after = $value->frequency * $minute_seconds;
            } else if( 'Days' == $value->day_or_hour ) {
                $time_to_send_template_after = $value->frequency * $day_seconds;
            } else if( 'Hours' == $value->day_or_hour ) {
                $time_to_send_template_after = $value->frequency * $hour_seconds;
            }

			
			$opened_emails = $wpdb->get_var( $wpdb->prepare( 'SELECT count( DISTINCT( open.email_sent_id ) ) FROM ' . xorgcore_EMAIL_OPENED_TABLE . ' AS open INNER JOIN ' . xorgcore_EMAIL_SENT_HISTORY_TABLE . ' AS sent ON open.email_sent_id = sent.id WHERE sent.template_id = %d AND open.time_opened >= %s AND open.time_opened <= %s', $id, $start_date, $end_date ) ); //phpcs:ignore
			$open_rate     = $opened_emails > 0 && $ac_emails_count > 0 ? round( ( $opened_emails / $ac_emails_count ) * 100, $xorgcore_get_decimal ) : 0;

			
			$links_clicked = $wpdb->get_var( $wpdb->prepare( 'SELECT count( DISTINCT( link.email_sent_id ) ) FROM ' . xorgcore_EMAIL_CLICKED_TABLE . ' AS link INNER JOIN ' . xorgcore_EMAIL_SENT_HISTORY_TABLE . ' AS sent ON link.email_sent_id = sent.id WHERE sent.template_id = %d AND link.time_clicked >= %s AND link.time_clicked <= %s', $id, $start_date, $end_date ) ); //phpcs:ignore
			$links_rate    = $links_clicked > 0 && $ac_emails_count > 0 ? round( ( $links_clicked / $ac_emails_count ) * 100, $xorgcore_get_decimal ) : 0; 

			
			$coupon_rate = 0;
			if( stripos( $value->body, "{{coupon.code}}" ) ) {
				$coupon_rate = $links_clicked > 0 && $opened_emails > 0 ? round( ( $links_clicked / $opened_emails ) * 100, $xorgcore_get_decimal ) : 0;
			}
			

    		$xorgcore_recover_ratio = 0;
    	    if ( $ac_emails_count != 0 ) {
    	        $xorgcore_recover_ratio = $xorgcore_number_of_time_recover / $ac_emails_count * 100;
    	    }
    	    $rules = json_decode( $value->rules );
			$template_filter = '';
			if ( is_array( $rules ) && count( $rules ) > 0 ) {
				foreach ( $rules as $rule_list ) {
					if( 'send_to' === $rule_list->rule_type ) {
						if ( is_array( $rule_list->rule_value ) ) {
							foreach ( $rule_list->rule_value as $r_option ) {
								$template_filter .= $send_labels[ $r_option ] . ', ';
							}
						}
					}
				}
				$template_filter = rtrim( $template_filter, ', ' );
			}
    	    $return_templates_data[ $i ]->sr                  = $i + 1;
    	    $return_templates_data[ $i ]->id                  = $id;
    	    $return_templates_data[ $i ]->template_name       = $value->template_name;
    	    $return_templates_data[ $i ]->sent_time           = __( $frequency . " " . $day_or_hour . " After Abandonment", 'xcart-tr' );

    	    $return_templates_data[ $i ]->template_time       = $time_to_send_template_after;
    	    $return_templates_data[ $i ]->template_filter     = $template_filter;
    	    $return_templates_data[ $i ]->email_sent          = __( ( string )$ac_emails_count, 'xcart-tr' );
    	    $return_templates_data[ $i ]->percentage_recovery = round ( $xorgcore_recover_ratio , $xorgcore_get_decimal )."%";
			$return_templates_data[ $i ]->is_active           = $is_active;
			$return_templates_data[ $i ]->open_rate           = $open_rate;
			$return_templates_data[ $i ]->link_rate           = $links_rate;
			$return_templates_data[ $i ]->coupon_rate         = $coupon_rate;
    	    $i++;  		    
    	}
    	
        
        if( isset( $_GET['orderby'] ) && $_GET['orderby'] == 'template_name' ) {
        	if( isset( $_GET['order'] ) && $_GET['order'] == 'asc') {
        		usort( $return_templates_data, array( __CLASS__ ,"xorgcore_class_template_name_asc") ); 
        	} else {
        		usort( $return_templates_data, array( __CLASS__ ,"xorgcore_class_template_name_dsc") );
        	}
        }
        
        else if( isset( $_GET['orderby']) && $_GET['orderby'] == 'sent_time' ) {
            if( isset( $_GET['order'] ) && $_GET['order'] == 'asc' ) {
        		usort( $return_templates_data, array( __CLASS__ ,"xorgcore_class_sent_time_asc" ) );
        	} else {
        		usort( $return_templates_data, array( __CLASS__ ,"xorgcore_class_sent_time_dsc" ) );
        	}
        }

        if ( isset( $_GET['paged'] ) && $_GET['paged'] > 1 ) {
		    $page_number = $_GET['paged'] - 1;
		    $k           = $per_page * $page_number;
		}else {
		    $k           = 0;
		}
		 
		$return_templates_display = array();
		for ( $j = $k; $j < ( $k + $per_page ); $j++ ) {
            if ( isset( $return_templates_data[ $j ] ) ) {
		        $return_templates_display[ $j ] = $return_templates_data[ $j ];
		    }else {
		        break;
		    }
		}
        return apply_filters( 'xorgcore_templates_table_data', $return_templates_display );
	}
	
	function xorgcore_class_template_name_asc($value1,$value2) {
	    return strcasecmp($value1->template_name,$value2->template_name );
	}
	
	function xorgcore_class_template_name_dsc ($value1,$value2) {
	    return strcasecmp($value2->template_name,$value1->template_name );
	}
	
	function xorgcore_class_sent_time_asc($value1,$value2) {
	    return strnatcasecmp($value1->template_time,$value2->template_time );
	}
	
	function xorgcore_class_sent_time_dsc ($value1,$value2) {
	    return strnatcasecmp($value2->template_time,$value1->template_time );
	}
	
	public function column_default( $xorgcore_abandoned_orders, $column_name ) {
	    $value = '';
	    switch ( $column_name ) {	       
	        	            
			case 'activate' :
			    if( isset( $xorgcore_abandoned_orders->is_active ) ) {			       
			       $id        = $xorgcore_abandoned_orders->id;
			       $is_active = $xorgcore_abandoned_orders->is_active;
			       
			       $active    = ''; 
			       if( $is_active == '1' ) {
			           $active = "on";
			       } else {
			           $active = "off";
			       }
			       $active_text   = __( $active, 'xcart-tr' ); 
			       $value =  '<button type="button" class="xorgcore-switch xorgcore-toggle-template-status" '
					. 'xorgcore-template-id="'. $id .'" '
					. 'xorgcore-template-switch="'. ( $active ) . '">'
					. $active_text . '</button>'; 
			       
			    }
				break;	
				
			case 'template_filter' :
			    if( isset( $xorgcore_abandoned_orders->template_filter ) && '' != $xorgcore_abandoned_orders->template_filter) {
			        $value = $xorgcore_abandoned_orders->template_filter;
			    }else{
			    	$value = 'All';
			    }
				break;

			case 'open_rate':
			case 'link_rate':
			case 'coupon_rate':
				$value = isset( $xorgcore_abandoned_orders->$column_name ) ? $xorgcore_abandoned_orders->$column_name . '%' : '';
				break;

			default:			    
				$value = isset( $xorgcore_abandoned_orders->$column_name ) ? $xorgcore_abandoned_orders->$column_name : '';
				break;
	    }		
		return apply_filters( 'xorgcore_template_column_default', $value, $xorgcore_abandoned_orders, $column_name );
	}
	
	public function get_bulk_actions() {
	    return array(
	        'xorgcore_delete_template' => __( 'Delete', 'xcart-tr' )
	    );
	}
}
?>