<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit; 
}
if ( ! class_exists( 'xorgcore_Activate_Plugin' ) ) {
	
	class xorgcore_Activate_Plugin {
	    
		
		public static function xorgcore_create_cron_job(){
			add_filter( 'cron_schedules', array( __CLASS__, 'xorgcore_add_cron_schedule' ) );
			xorgcore_Activate_Plugin::xorgcore_schedule_cron_job();
		}
		
		
		public static function xorgcore_add_cron_schedule( $schedules ) {
		    $duration                = get_option( 'xorgcore_cron_time_duration' );
		    if ( isset( $duration ) && $duration > 0 ) {
		        $duration_in_seconds = $duration * 60;
		    } else {
		        $duration_in_seconds = 900;
		    }
		    $schedules['15_minutes'] = array(
		               'interval'    => $duration_in_seconds,  
		               'display'     => __( 'Once Every Fifteen Minutes' ),
		    );

		    $schedules['xorgcore_15_days'] = array(
		               'interval'    => 1296000, 
		               'display'     => __( 'Once Every Fifteen Days' ),
		    );
		    return $schedules;
		}
		
		public static function xorgcore_schedule_cron_job() {			
			
			if ( ! wp_next_scheduled( 'xorgcore_clear_carts' ) ) {
                wp_schedule_event( time(), 'daily', 'xorgcore_clear_carts' );
		    }
		}

	    
	    public static function xorgcore_activate() {

	    	
	    	if ( is_multisite() ) {
        		
        		$blog_list = get_sites();
        		foreach( $blog_list as $blog_list_key => $blog_list_value ) {
             		if( $blog_list_value->blog_id > 1 ){ 
                		$blog_id = $blog_list_value->blog_id;
                		self::xorgcore_process_activate( $blog_id );
            		} else { 
            			self::xorgcore_process_activate();
            		}
            	}
            } else { 
            	self::xorgcore_process_activate();
            }
        }

        
		static function xorgcore_process_activate( $blog_id = 0 ) {
			global $woocommerce, $wpdb;

			$db_prefix = ( $blog_id === 0 ) ? $wpdb->prefix : $wpdb->prefix . $blog_id . "_";

		    $xorgcore_collate = '';
		    if ( $wpdb->has_cap( 'collation' ) ) {
		        $xorgcore_collate = $wpdb->get_charset_collate();
		    }
		    $sql = "CREATE TABLE IF NOT EXISTS ". $db_prefix . "xcart_et" ." (
		            `id` int(11) NOT NULL AUTO_INCREMENT,
		            `subject` text COLLATE utf8_unicode_ci NOT NULL,
		            `body` mediumtext COLLATE utf8_unicode_ci NOT NULL,
		            `is_active` enum('0','1') COLLATE utf8_unicode_ci NOT NULL,
		            `frequency` int(11) NOT NULL,
		            `day_or_hour` enum('Minutes','Days','Hours') COLLATE utf8_unicode_ci NOT NULL,
		            `coupon_code` varchar(50) COLLATE utf8_unicode_ci NOT NULL,
		            `template_name` text COLLATE utf8_unicode_ci NOT NULL,
		            `default_template` int(11) COLLATE utf8_unicode_ci NOT NULL,
		            `discount` varchar(50) COLLATE utf8_unicode_ci NOT NULL,
		            `discount_type` varchar(50) COLLATE utf8_unicode_ci NOT NULL,
		            `discount_shipping` varchar(50) COLLATE utf8_unicode_ci NOT NULL,
					`discount_expiry` varchar(50) COLLATE utf8_unicode_ci NOT NULL,
					`individual_use` enum('0','1') COLLATE utf8_unicode_ci NOT NULL,
		            `generate_unique_coupon_code` enum('0','1') COLLATE utf8_unicode_ci NOT NULL,
		            `is_wc_template` enum('0','1') COLLATE utf8_unicode_ci NOT NULL,
					`wc_email_header` varchar(50) COLLATE utf8_unicode_ci NOT NULL,
					`match_rules` VARCHAR(50) COLLATE utf8_unicode_ci DEFAULT 'all' NOT NULL,
					`rules` VARCHAR(500) COLLATE utf8_unicode_ci NOT NULL,
		            `activated_time` int(11) NOT NULL,
		            PRIMARY KEY (`id`)
		            ) $xorgcore_collate AUTO_INCREMENT=1 ";
		    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		    $wpdb->query( $sql );

		    $sql_query = "CREATE TABLE IF NOT EXISTS ". $db_prefix . "xcart_sent" ." (
		                `id` int(11) NOT NULL auto_increment,
		                `template_id` varchar(40) collate utf8_unicode_ci NOT NULL,
		                `abandoned_order_id` int(11) NOT NULL,
		                `sent_time` datetime NOT NULL,
		                `sent_email_id` text COLLATE utf8_unicode_ci NOT NULL,
		                `recovered_order` enum('0','1') COLLATE utf8_unicode_ci NOT NULL,
		                 PRIMARY KEY  (`id`),
		                 INDEX order_id (abandoned_order_id)
		                ) $xorgcore_collate AUTO_INCREMENT=1 ";
		    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		    $wpdb->query( $sql_query );

		    $opened_query = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_om" . " (
		                    `id` int(11) NOT NULL AUTO_INCREMENT,
		                    `email_sent_id` int(11) NOT NULL,
		                    `time_opened` datetime NOT NULL,
		                    PRIMARY KEY (`id`)
		                    ) $xorgcore_collate COMMENT='store the primary key id of opened email template' AUTO_INCREMENT=1 ";
		    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		    $wpdb->query( $opened_query );

		    $clicked_query = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_link_clicked_email" . " (
		                    `id` int(11) NOT NULL AUTO_INCREMENT,
		                    `email_sent_id` int(11) NOT NULL,
		                    `link_clicked` varchar(60) COLLATE utf8_unicode_ci NOT NULL,
		                    `time_clicked` datetime NOT NULL,
		                    PRIMARY KEY (`id`)
		                    ) $xorgcore_collate COMMENT='store the link clicked in sent email template' AUTO_INCREMENT=1 ";
		    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		    $wpdb->query( $clicked_query );

		    $history_query = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_ac_history" . " (
		                    `id` int(11) NOT NULL AUTO_INCREMENT,
		                    `user_id` int(11) NOT NULL,
		                    `abandoned_cart_info` text COLLATE utf8_unicode_ci NOT NULL,
		                    `abandoned_cart_time` int(11) NOT NULL,
		                    `cart_ignored` enum('0','1','2','3','4') COLLATE utf8_unicode_ci NOT NULL,
		                    `recovered_cart` int(11) NOT NULL,
		                    `unsubscribe_link` enum('0','1') COLLATE utf8_unicode_ci NOT NULL,
		                    `user_type` text,
		                    `language` varchar(50) COLLATE utf8_unicode_ci NOT NULL,
		                    `session_id` varchar(50) COLLATE utf8_unicode_ci NOT NULL,
		                    `ip_address` longtext COLLATE utf8_unicode_ci NOT NULL,
		                    `manual_email` varchar(50) COLLATE utf8_unicode_ci NOT NULL,
							`xorgcore_trash` varchar(1) COLLATE utf8_unicode_ci NOT NULL,
							`checkout_link` varchar(200) COLLATE utf8_unicode_ci NOT NULL,
		                    PRIMARY KEY (`id`),
		                    INDEX id (id)
		                    ) $xorgcore_collate";
		    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		    $wpdb->query( $history_query );

		    $ac_guest_history_query      = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_guest_ac_history" . " (
		                                    `id` int(15) NOT NULL AUTO_INCREMENT,
		                                    `billing_first_name` text,
		                                    `billing_last_name` text,
		                                    `billing_country` text,
		                                    `billing_company_name` text,
		                                    `billing_address_1` text,
		                                    `billing_address_2` text,
		                                    `billing_city` text,
		                                    `billing_county` text,
		                                    `billing_zipcode` text,
		                                    `email_id` text,
		                                    `phone` text,
		                                    `ship_to_billing` text,
		                                    `order_notes` text,
		                                    `shipping_first_name` text,
		                                    `shipping_last_name` text,
		                                    `shipping_company_name` text,
		                                    `shipping_address_1` text,
		                                    `shipping_address_2` text,
		                                    `shipping_city` text,
		                                    `shipping_county` text,
		                                    `shipping_zipcode` text,
		                                    `shipping_charges` double,
		                                    PRIMARY KEY (`id`),
		                                    INDEX id (id)
		                                    ) $xorgcore_collate AUTO_INCREMENT=63000000";
		    require_once( ABSPATH . 'wp-admin/includes/upgrade.php');
		    $wpdb->query( $ac_guest_history_query );
		    if( $blog_id === 0 ) {
		    	update_option( 'xorgcore_alter_guest_columns', '1', 'no' );
		    } else {
		    	update_blog_option( $blog_id, 'xorgcore_alter_guest_columns', '1' );
			}
		    
		    $aelia_table = $db_prefix . "xcart_currency";

            $aelia_sql = "CREATE TABLE IF NOT EXISTS $aelia_table (
                    `id` int(11) NOT NULL AUTO_INCREMENT,
                    `abandoned_cart_id` int(11) COLLATE utf8_unicode_ci NOT NULL,
                    `acfac_currency` text COLLATE utf8_unicode_ci NOT NULL,
                    `date_time` TIMESTAMP on update CURRENT_TIMESTAMP COLLATE utf8_unicode_ci NOT NULL DEFAULT CURRENT_TIMESTAMP,
                    PRIMARY KEY (`id`)
                    ) $xorgcore_collate AUTO_INCREMENT=1 ";           
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
            $wpdb->query( $aelia_sql );

            $default_template = new xorgcore_Default_Settings;
            
            
		    $check_table_empty  = $wpdb->get_var( "SELECT COUNT(*) FROM `" . $db_prefix . "xcart_et" . "`" );
	            if ( 0 == $check_table_empty ) {
	                $default_template->xorgcore_create_default_templates( $db_prefix, $blog_id );
	                if( $blog_id === 0 ) {
	                	update_option( "xorgcore_ac_default_templates_installed", "yes" );
	                } else {
	                	update_blog_option( $blog_id, "xorgcore_ac_default_templates_installed", "yes" );
	                }
	            }
	        
	        if( $blog_id === 0 ) {
	        	$default_settings_created = get_option( 'ac_enable_cart_emails' );
	        } else {
	        	$default_settings_created = get_blog_option( $blog_id, 'ac_enable_cart_emails' );
	        }
		    //Default settings, if option table do not have any entry.
		    if ( ! $default_settings_created ) {
		        
		        $default_template->xorgcore_create_default_settings( $blog_id );
		    }

		    
		    if( $blog_id === 0 ) {
	        	if( ! get_option( 'ac_track_guest_cart_from_cart_page' ) ) {
	        		add_option( 'ac_track_guest_cart_from_cart_page', 'on' );
	        	}
	        } else {
	        	if( ! get_blog_option( $blog_id, 'ac_track_guest_cart_from_cart_page' ) ) {
	        		add_blog_option( $blog_id, 'ac_track_guest_cart_from_cart_page', 'on' );
	        	}
	        }

		    
			xorgcore_Activate_Plugin::xorgcore_add_atc_data( $blog_id );
			
			
			$sql_parent = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_notifications" . " (
                			`id` int(11) NOT NULL AUTO_INCREMENT,
                			`subject` text COLLATE utf8mb4_unicode_ci,
                			`body` mediumtext COLLATE utf8mb4_unicode_ci NOT NULL,
                			`type` text COLLATE utf8mb4_unicode_ci NOT NULL,
                			`is_active` enum('0','1') COLLATE utf8mb4_unicode_ci NOT NULL,
                			`frequency` text NOT NULL,
                			`coupon_code` varchar(50) COLLATE utf8mb4_unicode_ci NOT NULL,
                			`default_template` enum('0','1') COLLATE utf8mb4_unicode_ci NOT NULL,
                			PRIMARY KEY (`id`)
                			) $xorgcore_collate AUTO_INCREMENT=1 ";
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php');
			$wpdb->query( $sql_parent );
				
			$sql_meta = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_actionscheduler_claims" . " (
                			`meta_id` int(11) NOT NULL AUTO_INCREMENT,
                			`template_id` int(11) NOT NULL,
                			`meta_key` text COLLATE utf8mb4_unicode_ci NOT NULL,
                			`meta_value` text COLLATE utf8mb4_unicode_ci,
                			PRIMARY KEY(`meta_id`)
                			) $xorgcore_collate AUTO_INCREMENT=1";
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php');
			$wpdb->query( $sql_meta );

			$sql_tinyurls = "CREATE TABLE IF NOT EXISTS " . $db_prefix . "xcart_shortlink" . " (
                    			`id` int(11) NOT NULL AUTO_INCREMENT,
                    			`cart_id` int(11) NOT NULL,
                    			`template_id` int(11) NOT NULL,
                    			`long_url` VARCHAR(255) COLLATE utf8mb4_unicode_ci NOT NULL,
                    			`short_code` VARCHAR(10) COLLATE utf8mb4_unicode_ci NOT NULL,
                    			`date_created` int(11) NOT NULL,
                    			`counter` int(11) NOT NULL DEFAULT '0',
                    			`notification_data` VARCHAR(255) COLLATE utf8mb4_unicode_ci NOT NULL,
                    			PRIMARY KEY (`id`),
                    			KEY short_code (`short_code`)
                    			) $xorgcore_collate AUTO_INCREMENT=1000000";
				
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php');
			$wpdb->query( $sql_tinyurls );
				
			$check_query = "SELECT COUNT(id) FROM " . $db_prefix . "xcart_notifications" . " WHERE `default_template` = '1'";
			 
			$get_count = $wpdb->get_var( $check_query );

            $default_fb_body = array( 
                '{"header":"We saved your cart","subheader":"Purchase now before they are out of stock","header_image":"' . xorgcore_PLUGIN_URL . '/includes/fb-recovery/assets/css/images/carts_div.png","checkout_text":"Checkout Now!","unsubscribe_text":"Unsubscribe"}',
                '{"header":"You left some items in your cart","subheader":"We have saved some items in your cart","header_image":"' . xorgcore_PLUGIN_URL . '/includes/fb-recovery/assets/css/images/carts_div.png","checkout_text":"Checkout","unsubscribe_text":"Unsubscribe"}'
            );
			
			if( isset( $get_count ) && $get_count == 0 ) {

                
                $insert_templates = "INSERT INTO " . $db_prefix . "xcart_notifications" . " 
                            (`subject`, `body`, `type`, `is_active`, `frequency`, `coupon_code`, `default_template`) 
                            VALUES
                            ( 
                                NULL,
                                'کاربر {{user.name}}, مطلع شدیم شما یک سبد خرید رها شده در {{shop.name}} دارید. جهت تکمیل سبد خرید از طریق لینک زیر اقدان کنید. {{checkout.link}} ', 
                                'sms', 
                                '0', 
                                '30 minutes',
                                '', 
                                '1' 
                            ),
                            ( 
                                NULL,
                                'کاربر {{user.name}}, مطلع شدیم شما یک سبد خرید رها شده در {{shop.name}} دارید. جهت تکمیل سبد خرید از طریق لینک زیر اقدان کنید. {{checkout.link}} ', 
                                'sms', 
                                '0', 
                                '1 days', 
                                '',
                                '1' 
                            ),
                            ( 
                                'کاربر {{user.name}}, مطلع شدیم شما یک سبد خرید رها شده در {{shop.name}} دارید. جهت تکمیل سبد خرید از طریق لینک زیر اقدان کنید. {{checkout.link}} ',
                                '" . $default_fb_body[0] . "', 
                                'fb', 
                                '0', 
                                '30 minutes', 
                                '',
                                '1' 
                            ),
                            ( 
                                'کاربر {{user.name}}, مطلع شدیم شما یک سبد خرید رها شده در {{shop.name}} دارید. جهت تکمیل سبد خرید از طریق لینک زیر اقدان کنید. {{checkout.link}} ',
                                '" . $default_fb_body[1] . "', 
                                'fb', 
                                '0', 
                                '6 hours', 
                                '',
                                '1' 
                            )";

                $wpdb->query( $insert_templates );
            } else if( isset( $get_count ) && $get_count == 2 ) {

                
                
                $insert_fb = "INSERT INTO " . $db->prefix . "xcart_notifications" . " 
                            (`subject`, `body`, `type`, `is_active`, `frequency`, `coupon_code`, `default_template`) 
                            VALUES
                            ( 
                                '" . get_bloginfo( 'name' ) . ". Do not worry we saved them for you:',
                                '" . $default_fb_body[0] . "', 
                                'fb', 
                                '0', 
                                '30 minutes', 
                                '',
                                '1' 
                            ),
                            ( 
                                ' " . get_bloginfo( 'name' ) . ". Here is a list of items you left behind:',
                                '" . $default_fb_body[1] . "', 
                                'fb', 
                                '0', 
                                '6 hours', 
                                '',
                                '1' 
                            )";
                $wpdb->query( $insert_fb );
            }

            
            if( $blog_id === 0 ) {
	        	if( ! get_option( 'xorgcore_fb_consent_text' ) ) {
	        		add_option( 'xorgcore_fb_consent_text', 'Allow order status to be sent to Facebook Messenger' );
	        	}
	        } else {
	        	if( ! get_blog_option( $blog_id, 'xorgcore_fb_consent_text' ) ) {
	        		add_blog_option( $blog_id, 'xorgcore_fb_consent_text', 'Allow order status to be sent to Facebook Messenger' );
	        	}
	        }
		    
		}
		
		
		public static function xorgcore_add_atc_data( $blog_id ) {

			$xorgcore_atc_heading = 'ادامه فرآیند سفارش';
			$xorgcore_atc_heading_color = '#737f97';
			$xorgcore_atc_sub_text = 'لطفا شماره تماس خود را وارد نمایید.';
			$xorgcore_atc_sub_text_color = '#bbc9d2';
			$xorgcore_atc_email_field_placeholder = 'مثال: 09121112222';
			$xorgcore_atc_button = 'ادامه سفارش';
			$xorgcore_atc_button_color = '#0085ba';
			$xorgcore_atc_button_text_color = '#ffffff';
			$xorgcore_atc_non_mandatory_text = 'رد کردن';
			$xorgcore_atc_mandatory = 'خاموش';
			$xorgcore_atc_email_mandatory = 'روشن';
			$xorgcore_countdown_cart = 'روشن';
			$countdown_timer_msg = 'کد تخفیف <coupon_code> تا تاریخ <hh:mm:ss>. معتبر است.';

			if( $blog_id === 0 ) {
	        	if( ! get_option( 'xorgcore_heading_section_text_email' ) ) {
	        		add_option( 'xorgcore_heading_section_text_email', $xorgcore_atc_heading );
	        	}

	        	if ( !get_option( 'xorgcore_popup_heading_color_picker' ) ) {
					add_option( 'xorgcore_popup_heading_color_picker', $xorgcore_atc_heading_color );
				}

				if ( !get_option( 'xorgcore_text_section_text' ) ) {
					add_option( 'xorgcore_text_section_text', $xorgcore_atc_sub_text );
				}

				if ( !get_option( 'xorgcore_popup_text_color_picker' ) ) {
					add_option( 'xorgcore_popup_text_color_picker', $xorgcore_atc_sub_text_color );
				}

				if ( !get_option( 'xorgcore_email_placeholder_section_input_text' ) ) {
					add_option( 'xorgcore_email_placeholder_section_input_text', $xorgcore_atc_email_field_placeholder );
				}

				if ( !get_option( 'xorgcore_button_section_input_text' ) ) {
					add_option( 'xorgcore_button_section_input_text', $xorgcore_atc_button );
				}

				if ( !get_option( 'xorgcore_button_color_picker' ) ) {
					add_option( 'xorgcore_button_color_picker', $xorgcore_atc_button_color );
				}

				if ( !get_option( 'xorgcore_button_text_color_picker' ) ) {
					add_option( 'xorgcore_button_text_color_picker', $xorgcore_atc_button_text_color );
				}

			    if ( !get_option( 'xorgcore_non_mandatory_text' ) ) {
					add_option( 'xorgcore_non_mandatory_text', $xorgcore_atc_non_mandatory_text );
				}

			    if ( !get_option( 'xorgcore_atc_enable_modal' ) ) {
					add_option( 'xorgcore_atc_enable_modal', $xorgcore_atc_mandatory );
				}

			    if ( !get_option( 'xorgcore_atc_mandatory_email' ) ) {
					add_option( 'xorgcore_atc_mandatory_email', $xorgcore_atc_email_mandatory );
				}

				if( !get_option( 'xorgcore_countdown_cart' ) ) {
					add_option( 'xorgcore_countdown_cart', $xorgcore_countdown_cart );
				}

				if( !get_option( 'xorgcore_countdown_timer_msg' ) ) {
					add_option( 'xorgcore_countdown_timer_msg', $countdown_timer_msg );
				}

				if( !get_option( 'xorgcore_atc_coupon_validity_minutes' ) ) {
					add_option( 'xorgcore_atc_coupon_validity_minutes', true );
				}
	        } else {
	        	if( ! get_blog_option( $blog_id, 'xorgcore_heading_section_text_email' ) ) {
	        		add_blog_option( $blog_id, 'xorgcore_heading_section_text_email', $xorgcore_atc_heading );
	        	}

	        	if ( ! get_blog_option( $blog_id, 'xorgcore_popup_heading_color_picker' ) ) {
					add_blog_option( $blog_id, 'xorgcore_popup_heading_color_picker', $xorgcore_atc_heading_color );
				}

				if ( !get_blog_option( $blog_id, 'xorgcore_text_section_text' ) ) {
					add_blog_option( $blog_id, 'xorgcore_text_section_text', $xorgcore_atc_sub_text );
				}

				if ( !get_blog_option( $blog_id, 'xorgcore_popup_text_color_picker' ) ) {
					add_blog_option( $blog_id, 'xorgcore_popup_text_color_picker', $xorgcore_atc_sub_text_color );
				}

				if ( !get_blog_option( $blog_id, 'xorgcore_email_placeholder_section_input_text' ) ) {
					add_blog_option( $blog_id, 'xorgcore_email_placeholder_section_input_text', $xorgcore_atc_email_field_placeholder );
				}

				if ( !get_blog_option( $blog_id, 'xorgcore_button_section_input_text' ) ) {
					add_blog_option( $blog_id, 'xorgcore_button_section_input_text', $xorgcore_atc_button );
				}

				if ( !get_blog_option( $blog_id, 'xorgcore_button_color_picker' ) ) {
					add_blog_option( $blog_id, 'xorgcore_button_color_picker', $xorgcore_atc_button_color );
				}

				if ( !get_blog_option( $blog_id, 'xorgcore_button_text_color_picker' ) ) {
					add_blog_option( $blog_id, 'xorgcore_button_text_color_picker', $xorgcore_atc_button_text_color );
				}

			    if ( !get_blog_option( $blog_id, 'xorgcore_non_mandatory_text' ) ) {
					add_blog_option( $blog_id, 'xorgcore_non_mandatory_text', $xorgcore_atc_non_mandatory_text );
				}

			    if ( !get_blog_option( $blog_id, 'xorgcore_atc_enable_modal' ) ) {
					add_blog_option( $blog_id, 'xorgcore_atc_enable_modal', $xorgcore_atc_mandatory );
				}

			    if ( !get_blog_option( $blog_id, 'xorgcore_atc_mandatory_email' ) ) {
					add_blog_option( $blog_id, 'xorgcore_atc_mandatory_email', $xorgcore_atc_email_mandatory );
				}

				if( !get_blog_option( $blog_id, 'xorgcore_countdown_cart' ) ) {
					add_blog_option( $blog_id, 'xorgcore_countdown_cart', $xorgcore_countdown_cart );
				}

				if( !get_blog_option( $blog_id, 'xorgcore_countdown_timer_msg' ) ) {
					add_blog_option( $blog_id, 'xorgcore_countdown_timer_msg', $countdown_timer_msg );
				}
				
				if( !get_blog_option( $blog_id, 'xorgcore_atc_coupon_validity_minutes' ) ) {
					add_blog_option( $blog_id, 'xorgcore_atc_coupon_validity_minutes', true );
				}
	        }
		}
	}

	//$enable_email = get_option( 'ac_enable_cart_emails' );
	//if( 'on' == $enable_email ) {
		xorgcore_Activate_Plugin::xorgcore_create_cron_job();
	//}
}
